@@ -116,6 +116,14 @@ def subset(context, target, session: Optional[str], base_path: Optional[str], bu
             self._separator = s
 
         def test_path(self, path: TestPathLike):
+            if isinstance(path, str) and any(s in path for s in ('/**', '**/', '*.', "/*")):
+                for i in glob.iglob(path, recursive=True):
+                    if os.path.isdir(i):
+                        continue
+
+                    self.test_path(i)
+                return
+
             """register one test"""
             self.test_paths.append(self.to_test_path(path))
 
